summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorwtc%netscape.com <devnull@localhost>1998-09-20 00:18:18 +0000
committerwtc%netscape.com <devnull@localhost>1998-09-20 00:18:18 +0000
commit3627e09889e95d9408dd1373791041d7bcdd78f0 (patch)
treee04ea9b90c9616ec1ea94e1ded77e97f7448177e
parentc2adabf2d8ba6be1aaacfdf91a14bd2d630715b9 (diff)
downloadnspr-hg-3627e09889e95d9408dd1373791041d7bcdd78f0.tar.gz
Renamed the 'index' argument for PR_Get/SetThreadPrivate to 'tpdIndex'.
This is because BSD systems have a funciton named 'index' in <string.h>, and if you compile with the -Wshadow flag, gcc warns that our declaration of `index' shadows global declaration. Thanks to Ben Laurie <ben@algroup.co.uk> for the problem report and the suggested workaround.
-rw-r--r--pr/include/prthread.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/pr/include/prthread.h b/pr/include/prthread.h
index 3311f527..c9ff0bce 100644
--- a/pr/include/prthread.h
+++ b/pr/include/prthread.h
@@ -185,19 +185,19 @@ PR_EXTERN(PRStatus) PR_NewThreadPrivateIndex(
/*
** Define some per-thread-private data.
** "index" is an index into the per-thread private data table
** "priv" is the per-thread-private data
**
** If the per-thread private data table has a previously registered
** destructor function and a non-NULL per-thread-private data value,
** the destructor function is invoked.
**
-** This can return PR_FAILURE if index is invalid.
+** This can return PR_FAILURE if the index is invalid.
*/
-PR_EXTERN(PRStatus) PR_SetThreadPrivate(PRUintn index, void *priv);
+PR_EXTERN(PRStatus) PR_SetThreadPrivate(PRUintn tpdIndex, void *priv);
/*
** Recover the per-thread-private data for the current thread. "index" is
** the index into the per-thread private data table.
**
** The returned value may be NULL which is indistinguishable from an error
@@ -205,7 +205,7 @@ PR_EXTERN(PRStatus) PR_SetThreadPrivate(PRUintn index, void *priv);
**
** A thread can only get access to its own thread-specific-data.
*/
-PR_EXTERN(void*) PR_GetThreadPrivate(PRUintn index);
+PR_EXTERN(void*) PR_GetThreadPrivate(PRUintn tpdIndex);
/*
** This routine sets the interrupt request for a target thread. The interrupt
@@ -185,19 +185,19 @@ PR_EXTERN(PRStatus) PR_NewThreadPrivateIndex(
/*
** Define some per-thread-private data.
-** "index" is an index into the per-thread private data table
+** "tpdIndex" is an index into the per-thread private data table
** "priv" is the per-thread-private data
**
@@ -185,19 +185,19 @@ PR_EXTERN(PRStatus) PR_NewThreadPrivateIndex(
/*
-** Recover the per-thread-private data for the current thread. "index" is
+** Recover the per-thread-private data for the current thread. "tpdIndex" is
** the index into the per-thread private data table.
**